"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var structures_1 = require("../structures");
var enums_1 = require("../enums");
var utils_1 = require("../utils");
var PacketHandler = /** @class */ (function () {
    function PacketHandler(client) {
        this.client = client;
    }
    PacketHandler.prototype[enums_1.identifiers.loginReady] = function () {
        this.client.emit("loginReady");
    };
    PacketHandler.prototype[enums_1.identifiers.oldPacket] = function (conn, packet) {
        var data = packet.readUTF().split(String.fromCharCode(1));
        var a = data.splice(0, 1)[0];
        var ccc = (a.charCodeAt(0) << 8) | a.charCodeAt(1);
        this.client.handleOldPacket(conn, ccc, data);
    };
    PacketHandler.prototype[enums_1.identifiers.handshakeOk] = function (conn, packet) {
        this.client.onlinePlayers = packet.readUnsignedInt();
        this.client.language = packet.readUTF();
        packet.readUTF(); // country;
        this.client.authServer = packet.readUnsignedInt();
        this.client.setSystemInfo("en", "Linux", "LNX 29,0,0,140");
        this.client.startHeartbeat();
    };
    PacketHandler.prototype[enums_1.identifiers.fingerprint] = function (conn, packet) {
        conn.fingerprint = packet.readByte();
    };
    PacketHandler.prototype[enums_1.identifiers.bulleConnection] = function (conn, packet) {
        var _this = this;
        var timestamp = packet.readUnsignedInt();
        var playerId = packet.readUnsignedInt();
        var pcode = packet.readUnsignedInt();
        var host = packet.readUTF();
        packet
            .readUTF()
            .split("-")
            .map(function (port) { return ~~port; }); // port
        if (this.client.bulle.open)
            this.client.bulle.close();
        this.client.bulle = new utils_1.Connection(this.client, "bulle");
        this.client.bulle.connect(host, this.client.ports[0]);
        this.client.bulle.on("connect", function () {
            _this.client.bulle.send(enums_1.identifiers.bulleConnection, new utils_1.ByteArray()
                .writeUnsignedInt(timestamp)
                .writeUnsignedInt(playerId)
                .writeUnsignedInt(pcode));
        });
    };
    PacketHandler.prototype[enums_1.identifiers.loggedIn] = function (conn, packet) {
        this.client.playerID = packet.readUnsignedInt();
        this.client.name = packet.readUTF();
        this.client.playingTime = packet.readUnsignedInt();
        this.client.connectionTime = new Date().getTime();
        this.client.community = packet.readByte();
        this.client.pcode = packet.readUnsignedInt();
        this.client.emit("login", this.client.name, this.client.pcode);
    };
    PacketHandler.prototype[enums_1.identifiers.loginError] = function (conn, packet) {
        this.client.emit("loginError", packet.readUnsignedByte(), packet.readUTF(), packet.readUTF());
    };
    PacketHandler.prototype[enums_1.identifiers.bulle] = function (conn, packet) {
        var code = packet.readUnsignedShort();
        if (code === 3) {
            this.client.emit("ready");
        }
        else {
            this.client.handleTribulle(code, packet);
        }
    };
    PacketHandler.prototype[enums_1.identifiers.luaChatLog] = function (conn, packet) {
        this.client.emit("luaLog", packet.readUTF());
    };
    PacketHandler.prototype[enums_1.identifiers.roomMessage] = function (conn, packet) {
        var player = this.client.room.getPlayer(packet.readUTF());
        if (!player)
            return;
        var content = packet.readUTF();
        var message = new structures_1.RoomMessage(this.client, player, content);
        this.client.emit("roomMessage", message);
    };
    PacketHandler.prototype[enums_1.identifiers.roomChange] = function (conn, packet) {
        var before = this.client.room;
        var isPublic = packet.readBoolean(), name = packet.readUTF(), language = packet.readUTF();
        this.client.room = new structures_1.Room(this.client, isPublic, name, language);
        this.client.emit("roomChange", before, this.client.room);
    };
    PacketHandler.prototype[enums_1.identifiers.roomPlayerList] = function (conn, packet) {
        var before = this.client.room.playerList;
        this.client.room.playerList = [];
        var length = packet.readUnsignedShort();
        for (var i = 0; i < length; i++) {
            var player = new structures_1.RoomPlayer(this.client).read(packet);
            this.client.room.playerList.push(player);
        }
        this.client.player = this.client.room.getPlayer(this.client.pcode);
        this.client.emit("roomUpdate", before, this.client.room.playerList);
    };
    PacketHandler.prototype[enums_1.identifiers.roomNewPlayer] = function (conn, packet) {
        var player = new structures_1.RoomPlayer(this.client).read(packet);
        if (this.client.room.getPlayer(player.pcode)) {
            this.client.emit("roomPlayerUpdate", this.client.room.getPlayer(player.pcode), player);
        }
        else {
            this.client.emit("roomPlayerJoin", player);
        }
        this.client.room.updatePlayer(player);
    };
    PacketHandler.prototype[enums_1.identifiers.languageChange] = function (conn, packet) {
        var language = packet.readUTF();
        var country = packet.readUTF();
        var readRight = packet.readBoolean();
        var readSpecialChar = packet.readBoolean();
        this.client.emit("languageChange", language, country, readRight, readSpecialChar);
    };
    return PacketHandler;
}());
exports.default = PacketHandler;
