"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var structures_1 = require("../structures");
var enums_1 = require("../enums");
var TribullePacketHandler = /** @class */ (function () {
    function TribullePacketHandler(client) {
        this.client = client;
    }
    TribullePacketHandler.prototype[enums_1.tribulle.whisper] = function (packet) {
        var author = packet.readUTF();
        var community = packet.readUnsignedInt();
        var sentTo = packet.readUTF();
        var content = packet.readUTF();
        var message = new structures_1.WhisperMessage(this.client, new structures_1.Player(this.client, author), community, sentTo, content);
        this.client.emit("whisper", message);
    };
    TribullePacketHandler.prototype[enums_1.tribulle.friendList] = function (packet) {
        var friends = [];
        var soulmate = new structures_1.Friend(this.client).read(packet, true); // soulmate
        var hasSoulmate = !(soulmate.id === 0 && soulmate.name === "");
        if (hasSoulmate)
            friends.push(soulmate);
        var totalFriends = packet.readUnsignedShort();
        while (totalFriends--) {
            friends.push(new structures_1.Friend(this.client).read(packet, false));
        }
        this.client.emit("friendList", friends, hasSoulmate ? soulmate.name : null);
    };
    TribullePacketHandler.prototype[enums_1.tribulle.friendConnect] = function (packet) {
        this.client.emit("friendConnect", packet.readUTF());
    };
    TribullePacketHandler.prototype[enums_1.tribulle.friendDisconnect] = function (packet) {
        this.client.emit("friendDisconnect", packet.readUTF());
    };
    TribullePacketHandler.prototype[enums_1.tribulle.friendChange] = function (packet) {
        this.client.emit("friendUpdate", new structures_1.Friend(this.client).read(packet, false));
    };
    TribullePacketHandler.prototype[enums_1.tribulle.channelWho] = function (packet) {
        packet.readUnsignedInt();
        packet.readUnsignedByte();
        var playerCount = packet.readUnsignedShort();
        var players = [];
        for (var i = 0; i < playerCount; i++) {
            var player = new structures_1.Player(this.client, packet.readUTF());
            players.push(player);
        }
        this.client.emit("channelWho", players);
    };
    TribullePacketHandler.prototype[enums_1.tribulle.channelLeave] = function (packet) {
        var channelName = packet.readUTF();
        this.client.emit("channelLeave", channelName);
    };
    TribullePacketHandler.prototype[enums_1.tribulle.channelJoin] = function (packet) {
        var channelName = packet.readUTF();
        this.client.emit("channelJoin", channelName);
    };
    TribullePacketHandler.prototype[enums_1.tribulle.channelMessage] = function (packet) {
        var author = new structures_1.Player(this.client, packet.readUTF());
        var community = packet.readUnsignedInt();
        var channelName = packet.readUTF();
        var content = packet.readUTF();
        var message = new structures_1.ChannelMessage(this.client, author, content, community, channelName);
        this.client.emit("channelMessage", message);
    };
    TribullePacketHandler.prototype[enums_1.tribulle.tribeMessage] = function (packet) {
        var author = new structures_1.Player(this.client, packet.readUTF());
        var message = new structures_1.Message(this.client, author, packet.readUTF());
        this.client.emit("tribeMessage", message);
    };
    TribullePacketHandler.prototype[enums_1.tribulle.tribeMemberConnect] = function (packet) {
        this.client.emit("tribeMemberConnect", packet.readUTF());
    };
    TribullePacketHandler.prototype[enums_1.tribulle.tribeMemberDisconnect] = function (packet) {
        this.client.emit("tribeMemberDisconnect", packet.readUTF());
    };
    return TribullePacketHandler;
}());
exports.default = TribullePacketHandler;
